@@ -13,7 +13,8 @@ import json
 import six
 
 from .exceptions import (
-    OrganizationNotFoundException, LoginError,
+    ConnectionError, OrganizationNotFoundException, LoginError,
+    MalformedURLException, MissingEndpointException,
     PlatformException, PlatformResponseException
 )
 
@@ -134,8 +135,15 @@ class Connection(object):
 
     def login(self):
         """Attempts to create a connection to the platform"""
-        link_request = requests.get(
-            self.__build_url(organization=self.__organization))
+        platform_url = self.__build_url(organization=self.__organization)
+
+        try:
+            link_request = requests.get(platform_url)
+        except (requests.exceptions.MissingSchema,
+                requests.exceptions.InvalidSchema):
+            raise MalformedURLException('Invalid schema')
+        except requests.exceptions.RequestException:
+            raise ConnectionError('Unable to connect to the platform')
 
         if link_request.status_code == 404:
             raise OrganizationNotFoundException()
@@ -206,7 +214,10 @@ class Connection(object):
             data = self.get(next_link)
             for (key, link) in data['links'].iteritems():
                 self.__link_cache[self.__generate_cachekey(key)] = link
-            next_link = data['links'][resource_path[0]]
+            if resource_path[0] in data['links']:
+                next_link = data['links'][resource_path[0]]
+            else:
+                raise MissingEndpointException('Missing endpoint')
             resource_path = resource_path[1:]
 
         return next_link
